@@ -19,7 +19,7 @@ use File::Basename ();
 use File::Path ();
 use File::Spec ();
 use vars qw($VERSION $urllist);
-$VERSION = sprintf "%.6f", substr(q$Rev: 1612 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 2015 $,4)/1000000 + 5.4;
 
 =head1 NAME
 
@@ -639,6 +639,18 @@ substitute. You can then revisit this dialog with
         $CPAN::Config->{show_upload_date} = ($ans =~ /^[y1]/i ? 1 : 0);
     }
 
+    #
+    #== verbosity at the end of the r command
+    #
+    if (!$matcher
+        or 'show_unparsable_versions' =~ /$matcher/
+        or 'show_zero_versions' =~ /$matcher/
+       ) {
+        $CPAN::Frontend->myprint($prompts{show_unparsable_or_zero_versions_intro});
+        my_yn_prompt(show_unparsable_versions => 0, $matcher);
+        my_yn_prompt(show_zero_versions => 0, $matcher);
+    }
+
     #
     #= MIRRORED.BY and conf_sites()
     #
@@ -1297,7 +1309,7 @@ Your choice: },
 make_arg => qq{Parameters for the 'make' command?
 Typical frequently used setting:
 
-    -j3              # dual processor system
+    -j3              # dual processor system (on GNU make)
 
 Your choice: },
 
@@ -1552,6 +1564,18 @@ to a config variable are always automatically committed to disk.
 
 auto_commit => qq{Always commit changes to config variables to disk?},
 
+show_unparsable_or_zero_versions_intro => qq{
+
+During the 'r' command CPAN.pm finds modules without version number or
+with a version number of zero. When the command finishes, it prints a
+short report about this. If you want this report to be very verbose,
+say yes to the following variable(s).
+
+},
+
+show_unparsable_versions => q{Show all individual modules that have no $VERSION?},
+show_zero_versions => q{Show all individual modules that have a $VERSION of zero?},
+
               );
 
 die "Coding error in \@prompts declaration.  Odd number of elements, above"
